//! Pre HTML codegen phase
use crate::compiler::data::{Atom, Text, Enclosure, EnclosureKind};
use crate::backend::{Ast, Tag};




